summaryrefslogtreecommitdiffstats
path: root/src/main/java
diff options
context:
space:
mode:
Diffstat (limited to 'src/main/java')
-rw-r--r--src/main/java/org/bukkit/Material.java19
1 files changed, 12 insertions, 7 deletions
diff --git a/src/main/java/org/bukkit/Material.java b/src/main/java/org/bukkit/Material.java
index 90a01e03..83f8eca1 100644
--- a/src/main/java/org/bukkit/Material.java
+++ b/src/main/java/org/bukkit/Material.java
@@ -2781,9 +2781,9 @@ public enum Material implements Keyed {
/**
* Attempts to match the Material with the given name.
* <p>
* This is a match lookup; names will be converted to uppercase, then
* stripped of special characters in an attempt to format it like the
* enum.
*
* @param name Name of the material to get
* @return Material if found, or null
@@ -2795,9 +2795,9 @@ public enum Material implements Keyed {
/**
* Attempts to match the Material with the given name.
* <p>
* This is a match lookup; names will be converted to uppercase, then
* stripped of special characters in an attempt to format it like the
* enum.
*
* @param name Name of the material to get
* @param legacyName whether this is a legacy name
@@ -2806,7 +2806,12 @@ public enum Material implements Keyed {
public static Material matchMaterial(final String name, boolean legacyName) {
Validate.notNull(name, "Name cannot be null");
- String filtered = name.toUpperCase(java.util.Locale.ENGLISH);
+ String filtered = name;
+ if (filtered.startsWith(NamespacedKey.MINECRAFT + ":")) {
+ filtered = filtered.substring((NamespacedKey.MINECRAFT + ":").length());
+ }
+
+ filtered = filtered.toUpperCase(java.util.Locale.ENGLISH);
filtered = filtered.replaceAll("\\s+", "_").replaceAll("\\W", "");
return getMaterial(filtered, legacyName);
@@ -2781,9 +2781,9 @@ public enum Material implements Keyed {
* Attempts to match the Material with the given name.
* <p>
- * This is a match lookup; names will be converted to uppercase, then
- * stripped of special characters in an attempt to format it like the
- * enum.
+ * This is a match lookup; names will be stripped of the "minecraft:"
+ * namespace, converted to uppercase, then stripped of special characters in
+ * an attempt to format it like the enum.
*
* @param name Name of the material to get
@@ -2795,9 +2795,9 @@ public enum Material implements Keyed {
* Attempts to match the Material with the given name.
* <p>
- * This is a match lookup; names will be converted to uppercase, then
- * stripped of special characters in an attempt to format it like the
- * enum.
+ * This is a match lookup; names will be stripped of the "minecraft:"
+ * namespace, converted to uppercase, then stripped of special characters in
+ * an attempt to format it like the enum.
*
* @param name Name of the material to get